@@ -12,9 +12,12 @@
 
 #include <QWeakPointer>
 
+#include <memory>
+
 namespace Akregator
 {
 class FeedList;
+class DeleteSubscriptionCommandPrivate;
 
 class DeleteSubscriptionCommand : public Command
 {
@@ -33,8 +36,8 @@ private:
     void doAbort() override;
 
 private:
-    class Private;
-    Private *const d;
+    friend class DeleteSubscriptionCommandPrivate;
+    std::unique_ptr<DeleteSubscriptionCommandPrivate> const d;
 };
 }
 
